guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

02/13: gnu: gitless: Add bash-minimal to inputs, use gexps.


From: guix-commits
Subject: 02/13: gnu: gitless: Add bash-minimal to inputs, use gexps.
Date: Fri, 20 Oct 2023 00:24:48 -0400 (EDT)

apteryx pushed a commit to branch core-updates
in repository guix.

commit 04031f4c16f38b2653797b9942d4da143f501cbb
Author: Maxim Cournoyer <maxim.cournoyer@gmail.com>
AuthorDate: Thu Oct 19 23:49:22 2023 -0400

    gnu: gitless: Add bash-minimal to inputs, use gexps.
    
    * gnu/packages/version-control.scm (gitless)
    [arguments]: Use gexps.
    [inputs]: Add bash-minimal.
    
    Change-Id: I6f9c8661b739493ff48e114b6b063ecf12b8236a
---
 gnu/packages/version-control.scm | 73 ++++++++++++++++++++--------------------
 1 file changed, 36 insertions(+), 37 deletions(-)

diff --git a/gnu/packages/version-control.scm b/gnu/packages/version-control.scm
index c4aea72073..6875f2b927 100644
--- a/gnu/packages/version-control.scm
+++ b/gnu/packages/version-control.scm
@@ -776,44 +776,43 @@ logs to GNU ChangeLog format.")
        (file-name (git-file-name name version))))
     (build-system python-build-system)
     (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (add-before 'build 'loosen-requirements
-           (lambda _
-             (substitute* "setup.py"
-               ;; Using Guix's python-pygit2 1.1.0 appears to work fine…
-               (("pygit2==") "pygit2>="))
-             #t))
-         (add-before 'check 'prepare-for-tests
-           (lambda _
-             ;; Find the 'gl' command.
-             (rename-file "gl.py" "gl")
-             (setenv "PATH" (string-append (getcwd) ":" (getenv "PATH")))
-
-             ;; The tests try to run git as if it were already set up.
-             (setenv "HOME" (getcwd))
-             (invoke "git" "config" "--global" "user.email" "git@example.com")
-             (invoke "git" "config" "--global" "user.name" "Guix")))
-         (replace 'wrap
-           (lambda* (#:key inputs outputs #:allow-other-keys)
-             (let ((out (assoc-ref outputs "out"))
-                   (git (assoc-ref inputs "git")))
-               (wrap-program (string-append out "/bin/gl")
-                 `("PATH" ":" prefix (,(string-append git "/bin")))
-                 `("GUIX_PYTHONPATH" ":" =
-                   (,(string-append out "/lib/python"
-                                    ,(version-major+minor
-                                      (package-version python))
-                                    "/site-packages:")
-                    ,(getenv "GUIX_PYTHONPATH"))))
-               #t))))))
-    (native-inputs
-     `(("git-for-tests" ,git-minimal)))
+     #~(list
+        #:phases
+        (modify-phases %standard-phases
+          (add-before 'build 'loosen-requirements
+            (lambda _
+              (substitute* "setup.py"
+                ;; Using Guix's python-pygit2 1.1.0 appears to work fine…
+                (("pygit2==") "pygit2>="))))
+          (add-before 'check 'prepare-for-tests
+            (lambda _
+              ;; Find the 'gl' command.
+              (rename-file "gl.py" "gl")
+              (setenv "PATH" (string-append (getcwd) ":" (getenv "PATH")))
+
+              ;; The tests try to run git as if it were already set up.
+              (setenv "HOME" (getcwd))
+              (invoke "git" "config" "--global" "user.email" "git@example.com")
+              (invoke "git" "config" "--global" "user.name" "Guix")))
+          (replace 'wrap
+            (lambda* (#:key inputs #:allow-other-keys)
+              (let ((out #$output)
+                    (git (search-input-file inputs "bin/git")))
+                (wrap-program (string-append out "/bin/gl")
+                  `("PATH" ":" prefix (,(dirname git)))
+                  `("GUIX_PYTHONPATH" ":" =
+                    (,(string-append out "/lib/python"
+                                     #$(version-major+minor
+                                        (package-version python))
+                                     "/site-packages:")
+                     ,(getenv "GUIX_PYTHONPATH"))))))))))
+    (native-inputs (list git-minimal))
     (inputs
-     `(("git" ,git-minimal)
-       ("python-clint" ,python-clint)
-       ("python-pygit2" ,python-pygit2)
-       ("python-sh" ,python-sh)))
+     (list bash-minimal
+           git-minimal
+           python-clint
+           python-pygit2
+           python-sh))
     (home-page "https://gitless.com";)
     (synopsis "Simple version control system built on top of Git")
     (description



reply via email to

[Prev in Thread] Current Thread [Next in Thread]